@@ -267,8 +267,8 @@ def process_dataframe(
     # Restrict DF to desired granularity
     if granularity == "centroids":
         atoms = convert_structure_to_centroids(atoms)
-    # elif granularity == "atom":
-    #    atoms = atoms
+    elif granularity == "atom":
+        pass
     else:
         atoms = subset_structure_to_atom_type(atoms, granularity)
 
